# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/signed_url_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/signed_url_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)fsai_grpc_api/protos/signed_url_api.proto\"\'\n\x13GetSignedUrlRequest\x12\x10\n\x08url_path\x18\x01 \x01(\t\"*\n\x14GetSignedUrlResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t\"`\n GetSignedMissionExportUrlRequest\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\x05\x12\x14\n\x0cpackage_type\x18\x02 \x01(\t\x12\x11\n\tfile_type\x18\x03 \x01(\t\"7\n!GetSignedMissionExportUrlResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t2\xaf\x01\n\x0cSignedUrlApi\x12;\n\x0cGetSignedUrl\x12\x14.GetSignedUrlRequest\x1a\x15.GetSignedUrlResponse\x12\x62\n\x19GetSignedMissionExportUrl\x12!.GetSignedMissionExportUrlRequest\x1a\".GetSignedMissionExportUrlResponseb\x06proto3'
)




_GETSIGNEDURLREQUEST = _descriptor.Descriptor(
  name='GetSignedUrlRequest',
  full_name='GetSignedUrlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url_path', full_name='GetSignedUrlRequest.url_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=84,
)


_GETSIGNEDURLRESPONSE = _descriptor.Descriptor(
  name='GetSignedUrlResponse',
  full_name='GetSignedUrlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url', full_name='GetSignedUrlResponse.signed_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=128,
)


_GETSIGNEDMISSIONEXPORTURLREQUEST = _descriptor.Descriptor(
  name='GetSignedMissionExportUrlRequest',
  full_name='GetSignedMissionExportUrlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='GetSignedMissionExportUrlRequest.workflow_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package_type', full_name='GetSignedMissionExportUrlRequest.package_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='GetSignedMissionExportUrlRequest.file_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=226,
)


_GETSIGNEDMISSIONEXPORTURLRESPONSE = _descriptor.Descriptor(
  name='GetSignedMissionExportUrlResponse',
  full_name='GetSignedMissionExportUrlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url', full_name='GetSignedMissionExportUrlResponse.signed_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=283,
)

DESCRIPTOR.message_types_by_name['GetSignedUrlRequest'] = _GETSIGNEDURLREQUEST
DESCRIPTOR.message_types_by_name['GetSignedUrlResponse'] = _GETSIGNEDURLRESPONSE
DESCRIPTOR.message_types_by_name['GetSignedMissionExportUrlRequest'] = _GETSIGNEDMISSIONEXPORTURLREQUEST
DESCRIPTOR.message_types_by_name['GetSignedMissionExportUrlResponse'] = _GETSIGNEDMISSIONEXPORTURLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSignedUrlRequest = _reflection.GeneratedProtocolMessageType('GetSignedUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSIGNEDURLREQUEST,
  '__module__' : 'fsai_grpc_api.protos.signed_url_api_pb2'
  # @@protoc_insertion_point(class_scope:GetSignedUrlRequest)
  })
_sym_db.RegisterMessage(GetSignedUrlRequest)

GetSignedUrlResponse = _reflection.GeneratedProtocolMessageType('GetSignedUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSIGNEDURLRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.signed_url_api_pb2'
  # @@protoc_insertion_point(class_scope:GetSignedUrlResponse)
  })
_sym_db.RegisterMessage(GetSignedUrlResponse)

GetSignedMissionExportUrlRequest = _reflection.GeneratedProtocolMessageType('GetSignedMissionExportUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSIGNEDMISSIONEXPORTURLREQUEST,
  '__module__' : 'fsai_grpc_api.protos.signed_url_api_pb2'
  # @@protoc_insertion_point(class_scope:GetSignedMissionExportUrlRequest)
  })
_sym_db.RegisterMessage(GetSignedMissionExportUrlRequest)

GetSignedMissionExportUrlResponse = _reflection.GeneratedProtocolMessageType('GetSignedMissionExportUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSIGNEDMISSIONEXPORTURLRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.signed_url_api_pb2'
  # @@protoc_insertion_point(class_scope:GetSignedMissionExportUrlResponse)
  })
_sym_db.RegisterMessage(GetSignedMissionExportUrlResponse)



_SIGNEDURLAPI = _descriptor.ServiceDescriptor(
  name='SignedUrlApi',
  full_name='SignedUrlApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=286,
  serialized_end=461,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSignedUrl',
    full_name='SignedUrlApi.GetSignedUrl',
    index=0,
    containing_service=None,
    input_type=_GETSIGNEDURLREQUEST,
    output_type=_GETSIGNEDURLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignedMissionExportUrl',
    full_name='SignedUrlApi.GetSignedMissionExportUrl',
    index=1,
    containing_service=None,
    input_type=_GETSIGNEDMISSIONEXPORTURLREQUEST,
    output_type=_GETSIGNEDMISSIONEXPORTURLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIGNEDURLAPI)

DESCRIPTOR.services_by_name['SignedUrlApi'] = _SIGNEDURLAPI

# @@protoc_insertion_point(module_scope)
